# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class QueueConversationCallbackEventTopicCallbackMediaParticipant(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        QueueConversationCallbackEventTopicCallbackMediaParticipant - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'address': 'str',
            'start_time': 'datetime',
            'connected_time': 'datetime',
            'end_time': 'datetime',
            'start_hold_time': 'datetime',
            'purpose': 'str',
            'state': 'str',
            'direction': 'str',
            'disconnect_type': 'str',
            'held': 'bool',
            'wrapup_required': 'bool',
            'wrapup_prompt': 'str',
            'user': 'QueueConversationCallbackEventTopicUriReference',
            'queue': 'QueueConversationCallbackEventTopicUriReference',
            'team': 'QueueConversationCallbackEventTopicUriReference',
            'attributes': 'dict(str, str)',
            'error_info': 'QueueConversationCallbackEventTopicErrorBody',
            'script': 'QueueConversationCallbackEventTopicUriReference',
            'wrapup_timeout_ms': 'int',
            'wrapup_skipped': 'bool',
            'alerting_timeout_ms': 'int',
            'provider': 'str',
            'external_contact': 'QueueConversationCallbackEventTopicUriReference',
            'external_organization': 'QueueConversationCallbackEventTopicUriReference',
            'wrapup': 'QueueConversationCallbackEventTopicWrapup',
            'conversation_routing_data': 'QueueConversationCallbackEventTopicConversationRoutingData',
            'peer': 'str',
            'screen_recording_state': 'str',
            'flagged_reason': 'str',
            'journey_context': 'QueueConversationCallbackEventTopicJourneyContext',
            'start_acw_time': 'datetime',
            'end_acw_time': 'datetime',
            'outbound_preview': 'QueueConversationCallbackEventTopicDialerPreview',
            'voicemail': 'QueueConversationCallbackEventTopicVoicemail',
            'callback_numbers': 'list[str]',
            'callback_user_name': 'str',
            'skip_enabled': 'bool',
            'external_campaign': 'bool',
            'timeout_seconds': 'int',
            'callback_scheduled_time': 'datetime',
            'automated_callback_config_id': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'address': 'address',
            'start_time': 'startTime',
            'connected_time': 'connectedTime',
            'end_time': 'endTime',
            'start_hold_time': 'startHoldTime',
            'purpose': 'purpose',
            'state': 'state',
            'direction': 'direction',
            'disconnect_type': 'disconnectType',
            'held': 'held',
            'wrapup_required': 'wrapupRequired',
            'wrapup_prompt': 'wrapupPrompt',
            'user': 'user',
            'queue': 'queue',
            'team': 'team',
            'attributes': 'attributes',
            'error_info': 'errorInfo',
            'script': 'script',
            'wrapup_timeout_ms': 'wrapupTimeoutMs',
            'wrapup_skipped': 'wrapupSkipped',
            'alerting_timeout_ms': 'alertingTimeoutMs',
            'provider': 'provider',
            'external_contact': 'externalContact',
            'external_organization': 'externalOrganization',
            'wrapup': 'wrapup',
            'conversation_routing_data': 'conversationRoutingData',
            'peer': 'peer',
            'screen_recording_state': 'screenRecordingState',
            'flagged_reason': 'flaggedReason',
            'journey_context': 'journeyContext',
            'start_acw_time': 'startAcwTime',
            'end_acw_time': 'endAcwTime',
            'outbound_preview': 'outboundPreview',
            'voicemail': 'voicemail',
            'callback_numbers': 'callbackNumbers',
            'callback_user_name': 'callbackUserName',
            'skip_enabled': 'skipEnabled',
            'external_campaign': 'externalCampaign',
            'timeout_seconds': 'timeoutSeconds',
            'callback_scheduled_time': 'callbackScheduledTime',
            'automated_callback_config_id': 'automatedCallbackConfigId'
        }

        self._id = None
        self._name = None
        self._address = None
        self._start_time = None
        self._connected_time = None
        self._end_time = None
        self._start_hold_time = None
        self._purpose = None
        self._state = None
        self._direction = None
        self._disconnect_type = None
        self._held = None
        self._wrapup_required = None
        self._wrapup_prompt = None
        self._user = None
        self._queue = None
        self._team = None
        self._attributes = None
        self._error_info = None
        self._script = None
        self._wrapup_timeout_ms = None
        self._wrapup_skipped = None
        self._alerting_timeout_ms = None
        self._provider = None
        self._external_contact = None
        self._external_organization = None
        self._wrapup = None
        self._conversation_routing_data = None
        self._peer = None
        self._screen_recording_state = None
        self._flagged_reason = None
        self._journey_context = None
        self._start_acw_time = None
        self._end_acw_time = None
        self._outbound_preview = None
        self._voicemail = None
        self._callback_numbers = None
        self._callback_user_name = None
        self._skip_enabled = None
        self._external_campaign = None
        self._timeout_seconds = None
        self._callback_scheduled_time = None
        self._automated_callback_config_id = None

    @property
    def id(self):
        """
        Gets the id of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The id of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :param id: The id of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The name of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :param name: The name of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :type: str
        """
        
        self._name = name

    @property
    def address(self):
        """
        Gets the address of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The address of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: str
        """
        return self._address

    @address.setter
    def address(self, address):
        """
        Sets the address of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :param address: The address of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :type: str
        """
        
        self._address = address

    @property
    def start_time(self):
        """
        Gets the start_time of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The start_time of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: datetime
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """
        Sets the start_time of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :param start_time: The start_time of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :type: datetime
        """
        
        self._start_time = start_time

    @property
    def connected_time(self):
        """
        Gets the connected_time of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The connected_time of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: datetime
        """
        return self._connected_time

    @connected_time.setter
    def connected_time(self, connected_time):
        """
        Sets the connected_time of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :param connected_time: The connected_time of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :type: datetime
        """
        
        self._connected_time = connected_time

    @property
    def end_time(self):
        """
        Gets the end_time of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The end_time of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: datetime
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """
        Sets the end_time of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :param end_time: The end_time of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :type: datetime
        """
        
        self._end_time = end_time

    @property
    def start_hold_time(self):
        """
        Gets the start_hold_time of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The start_hold_time of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: datetime
        """
        return self._start_hold_time

    @start_hold_time.setter
    def start_hold_time(self, start_hold_time):
        """
        Sets the start_hold_time of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :param start_hold_time: The start_hold_time of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :type: datetime
        """
        
        self._start_hold_time = start_hold_time

    @property
    def purpose(self):
        """
        Gets the purpose of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The purpose of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: str
        """
        return self._purpose

    @purpose.setter
    def purpose(self, purpose):
        """
        Sets the purpose of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :param purpose: The purpose of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :type: str
        """
        
        self._purpose = purpose

    @property
    def state(self):
        """
        Gets the state of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The state of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :param state: The state of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :type: str
        """
        allowed_values = ["alerting", "dialing", "contacting", "offering", "connected", "disconnected", "terminated", "converting", "uploading", "transmitting", "scheduled", "none"]
        if state.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for state -> " + state)
            self._state = "outdated_sdk_version"
        else:
            self._state = state

    @property
    def direction(self):
        """
        Gets the direction of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The direction of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: str
        """
        return self._direction

    @direction.setter
    def direction(self, direction):
        """
        Sets the direction of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :param direction: The direction of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :type: str
        """
        allowed_values = ["inbound", "outbound"]
        if direction.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for direction -> " + direction)
            self._direction = "outdated_sdk_version"
        else:
            self._direction = direction

    @property
    def disconnect_type(self):
        """
        Gets the disconnect_type of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The disconnect_type of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: str
        """
        return self._disconnect_type

    @disconnect_type.setter
    def disconnect_type(self, disconnect_type):
        """
        Sets the disconnect_type of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :param disconnect_type: The disconnect_type of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :type: str
        """
        allowed_values = ["endpoint", "client", "system", "transfer", "timeout", "transfer.conference", "transfer.consult", "transfer.forward", "transfer.noanswer", "transfer.notavailable", "transport.failure", "error", "peer", "other", "spam", "uncallable"]
        if disconnect_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for disconnect_type -> " + disconnect_type)
            self._disconnect_type = "outdated_sdk_version"
        else:
            self._disconnect_type = disconnect_type

    @property
    def held(self):
        """
        Gets the held of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The held of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: bool
        """
        return self._held

    @held.setter
    def held(self, held):
        """
        Sets the held of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :param held: The held of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :type: bool
        """
        
        self._held = held

    @property
    def wrapup_required(self):
        """
        Gets the wrapup_required of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The wrapup_required of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: bool
        """
        return self._wrapup_required

    @wrapup_required.setter
    def wrapup_required(self, wrapup_required):
        """
        Sets the wrapup_required of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :param wrapup_required: The wrapup_required of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :type: bool
        """
        
        self._wrapup_required = wrapup_required

    @property
    def wrapup_prompt(self):
        """
        Gets the wrapup_prompt of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The wrapup_prompt of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: str
        """
        return self._wrapup_prompt

    @wrapup_prompt.setter
    def wrapup_prompt(self, wrapup_prompt):
        """
        Sets the wrapup_prompt of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :param wrapup_prompt: The wrapup_prompt of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :type: str
        """
        
        self._wrapup_prompt = wrapup_prompt

    @property
    def user(self):
        """
        Gets the user of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The user of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: QueueConversationCallbackEventTopicUriReference
        """
        return self._user

    @user.setter
    def user(self, user):
        """
        Sets the user of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :param user: The user of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :type: QueueConversationCallbackEventTopicUriReference
        """
        
        self._user = user

    @property
    def queue(self):
        """
        Gets the queue of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The queue of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: QueueConversationCallbackEventTopicUriReference
        """
        return self._queue

    @queue.setter
    def queue(self, queue):
        """
        Sets the queue of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :param queue: The queue of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :type: QueueConversationCallbackEventTopicUriReference
        """
        
        self._queue = queue

    @property
    def team(self):
        """
        Gets the team of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The team of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: QueueConversationCallbackEventTopicUriReference
        """
        return self._team

    @team.setter
    def team(self, team):
        """
        Sets the team of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :param team: The team of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :type: QueueConversationCallbackEventTopicUriReference
        """
        
        self._team = team

    @property
    def attributes(self):
        """
        Gets the attributes of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The attributes of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: dict(str, str)
        """
        return self._attributes

    @attributes.setter
    def attributes(self, attributes):
        """
        Sets the attributes of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :param attributes: The attributes of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :type: dict(str, str)
        """
        
        self._attributes = attributes

    @property
    def error_info(self):
        """
        Gets the error_info of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The error_info of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: QueueConversationCallbackEventTopicErrorBody
        """
        return self._error_info

    @error_info.setter
    def error_info(self, error_info):
        """
        Sets the error_info of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :param error_info: The error_info of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :type: QueueConversationCallbackEventTopicErrorBody
        """
        
        self._error_info = error_info

    @property
    def script(self):
        """
        Gets the script of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The script of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: QueueConversationCallbackEventTopicUriReference
        """
        return self._script

    @script.setter
    def script(self, script):
        """
        Sets the script of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :param script: The script of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :type: QueueConversationCallbackEventTopicUriReference
        """
        
        self._script = script

    @property
    def wrapup_timeout_ms(self):
        """
        Gets the wrapup_timeout_ms of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The wrapup_timeout_ms of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: int
        """
        return self._wrapup_timeout_ms

    @wrapup_timeout_ms.setter
    def wrapup_timeout_ms(self, wrapup_timeout_ms):
        """
        Sets the wrapup_timeout_ms of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :param wrapup_timeout_ms: The wrapup_timeout_ms of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :type: int
        """
        
        self._wrapup_timeout_ms = wrapup_timeout_ms

    @property
    def wrapup_skipped(self):
        """
        Gets the wrapup_skipped of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The wrapup_skipped of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: bool
        """
        return self._wrapup_skipped

    @wrapup_skipped.setter
    def wrapup_skipped(self, wrapup_skipped):
        """
        Sets the wrapup_skipped of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :param wrapup_skipped: The wrapup_skipped of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :type: bool
        """
        
        self._wrapup_skipped = wrapup_skipped

    @property
    def alerting_timeout_ms(self):
        """
        Gets the alerting_timeout_ms of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The alerting_timeout_ms of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: int
        """
        return self._alerting_timeout_ms

    @alerting_timeout_ms.setter
    def alerting_timeout_ms(self, alerting_timeout_ms):
        """
        Sets the alerting_timeout_ms of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :param alerting_timeout_ms: The alerting_timeout_ms of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :type: int
        """
        
        self._alerting_timeout_ms = alerting_timeout_ms

    @property
    def provider(self):
        """
        Gets the provider of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The provider of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: str
        """
        return self._provider

    @provider.setter
    def provider(self, provider):
        """
        Sets the provider of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :param provider: The provider of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :type: str
        """
        
        self._provider = provider

    @property
    def external_contact(self):
        """
        Gets the external_contact of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The external_contact of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: QueueConversationCallbackEventTopicUriReference
        """
        return self._external_contact

    @external_contact.setter
    def external_contact(self, external_contact):
        """
        Sets the external_contact of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :param external_contact: The external_contact of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :type: QueueConversationCallbackEventTopicUriReference
        """
        
        self._external_contact = external_contact

    @property
    def external_organization(self):
        """
        Gets the external_organization of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The external_organization of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: QueueConversationCallbackEventTopicUriReference
        """
        return self._external_organization

    @external_organization.setter
    def external_organization(self, external_organization):
        """
        Sets the external_organization of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :param external_organization: The external_organization of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :type: QueueConversationCallbackEventTopicUriReference
        """
        
        self._external_organization = external_organization

    @property
    def wrapup(self):
        """
        Gets the wrapup of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The wrapup of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: QueueConversationCallbackEventTopicWrapup
        """
        return self._wrapup

    @wrapup.setter
    def wrapup(self, wrapup):
        """
        Sets the wrapup of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :param wrapup: The wrapup of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :type: QueueConversationCallbackEventTopicWrapup
        """
        
        self._wrapup = wrapup

    @property
    def conversation_routing_data(self):
        """
        Gets the conversation_routing_data of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The conversation_routing_data of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: QueueConversationCallbackEventTopicConversationRoutingData
        """
        return self._conversation_routing_data

    @conversation_routing_data.setter
    def conversation_routing_data(self, conversation_routing_data):
        """
        Sets the conversation_routing_data of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :param conversation_routing_data: The conversation_routing_data of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :type: QueueConversationCallbackEventTopicConversationRoutingData
        """
        
        self._conversation_routing_data = conversation_routing_data

    @property
    def peer(self):
        """
        Gets the peer of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The peer of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: str
        """
        return self._peer

    @peer.setter
    def peer(self, peer):
        """
        Sets the peer of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :param peer: The peer of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :type: str
        """
        
        self._peer = peer

    @property
    def screen_recording_state(self):
        """
        Gets the screen_recording_state of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The screen_recording_state of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: str
        """
        return self._screen_recording_state

    @screen_recording_state.setter
    def screen_recording_state(self, screen_recording_state):
        """
        Sets the screen_recording_state of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :param screen_recording_state: The screen_recording_state of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :type: str
        """
        
        self._screen_recording_state = screen_recording_state

    @property
    def flagged_reason(self):
        """
        Gets the flagged_reason of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The flagged_reason of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: str
        """
        return self._flagged_reason

    @flagged_reason.setter
    def flagged_reason(self, flagged_reason):
        """
        Sets the flagged_reason of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :param flagged_reason: The flagged_reason of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :type: str
        """
        allowed_values = ["general"]
        if flagged_reason.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for flagged_reason -> " + flagged_reason)
            self._flagged_reason = "outdated_sdk_version"
        else:
            self._flagged_reason = flagged_reason

    @property
    def journey_context(self):
        """
        Gets the journey_context of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The journey_context of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: QueueConversationCallbackEventTopicJourneyContext
        """
        return self._journey_context

    @journey_context.setter
    def journey_context(self, journey_context):
        """
        Sets the journey_context of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :param journey_context: The journey_context of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :type: QueueConversationCallbackEventTopicJourneyContext
        """
        
        self._journey_context = journey_context

    @property
    def start_acw_time(self):
        """
        Gets the start_acw_time of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The start_acw_time of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: datetime
        """
        return self._start_acw_time

    @start_acw_time.setter
    def start_acw_time(self, start_acw_time):
        """
        Sets the start_acw_time of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :param start_acw_time: The start_acw_time of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :type: datetime
        """
        
        self._start_acw_time = start_acw_time

    @property
    def end_acw_time(self):
        """
        Gets the end_acw_time of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The end_acw_time of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: datetime
        """
        return self._end_acw_time

    @end_acw_time.setter
    def end_acw_time(self, end_acw_time):
        """
        Sets the end_acw_time of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :param end_acw_time: The end_acw_time of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :type: datetime
        """
        
        self._end_acw_time = end_acw_time

    @property
    def outbound_preview(self):
        """
        Gets the outbound_preview of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The outbound_preview of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: QueueConversationCallbackEventTopicDialerPreview
        """
        return self._outbound_preview

    @outbound_preview.setter
    def outbound_preview(self, outbound_preview):
        """
        Sets the outbound_preview of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :param outbound_preview: The outbound_preview of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :type: QueueConversationCallbackEventTopicDialerPreview
        """
        
        self._outbound_preview = outbound_preview

    @property
    def voicemail(self):
        """
        Gets the voicemail of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The voicemail of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: QueueConversationCallbackEventTopicVoicemail
        """
        return self._voicemail

    @voicemail.setter
    def voicemail(self, voicemail):
        """
        Sets the voicemail of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :param voicemail: The voicemail of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :type: QueueConversationCallbackEventTopicVoicemail
        """
        
        self._voicemail = voicemail

    @property
    def callback_numbers(self):
        """
        Gets the callback_numbers of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The callback_numbers of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: list[str]
        """
        return self._callback_numbers

    @callback_numbers.setter
    def callback_numbers(self, callback_numbers):
        """
        Sets the callback_numbers of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :param callback_numbers: The callback_numbers of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :type: list[str]
        """
        
        self._callback_numbers = callback_numbers

    @property
    def callback_user_name(self):
        """
        Gets the callback_user_name of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The callback_user_name of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: str
        """
        return self._callback_user_name

    @callback_user_name.setter
    def callback_user_name(self, callback_user_name):
        """
        Sets the callback_user_name of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :param callback_user_name: The callback_user_name of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :type: str
        """
        
        self._callback_user_name = callback_user_name

    @property
    def skip_enabled(self):
        """
        Gets the skip_enabled of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The skip_enabled of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: bool
        """
        return self._skip_enabled

    @skip_enabled.setter
    def skip_enabled(self, skip_enabled):
        """
        Sets the skip_enabled of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :param skip_enabled: The skip_enabled of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :type: bool
        """
        
        self._skip_enabled = skip_enabled

    @property
    def external_campaign(self):
        """
        Gets the external_campaign of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The external_campaign of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: bool
        """
        return self._external_campaign

    @external_campaign.setter
    def external_campaign(self, external_campaign):
        """
        Sets the external_campaign of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :param external_campaign: The external_campaign of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :type: bool
        """
        
        self._external_campaign = external_campaign

    @property
    def timeout_seconds(self):
        """
        Gets the timeout_seconds of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The timeout_seconds of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: int
        """
        return self._timeout_seconds

    @timeout_seconds.setter
    def timeout_seconds(self, timeout_seconds):
        """
        Sets the timeout_seconds of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :param timeout_seconds: The timeout_seconds of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :type: int
        """
        
        self._timeout_seconds = timeout_seconds

    @property
    def callback_scheduled_time(self):
        """
        Gets the callback_scheduled_time of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The callback_scheduled_time of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: datetime
        """
        return self._callback_scheduled_time

    @callback_scheduled_time.setter
    def callback_scheduled_time(self, callback_scheduled_time):
        """
        Sets the callback_scheduled_time of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :param callback_scheduled_time: The callback_scheduled_time of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :type: datetime
        """
        
        self._callback_scheduled_time = callback_scheduled_time

    @property
    def automated_callback_config_id(self):
        """
        Gets the automated_callback_config_id of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :return: The automated_callback_config_id of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :rtype: str
        """
        return self._automated_callback_config_id

    @automated_callback_config_id.setter
    def automated_callback_config_id(self, automated_callback_config_id):
        """
        Sets the automated_callback_config_id of this QueueConversationCallbackEventTopicCallbackMediaParticipant.


        :param automated_callback_config_id: The automated_callback_config_id of this QueueConversationCallbackEventTopicCallbackMediaParticipant.
        :type: str
        """
        
        self._automated_callback_config_id = automated_callback_config_id

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class DialerCampaignRuleConfigChangeCampaignRuleAction(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        DialerCampaignRuleConfigChangeCampaignRuleAction - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'parameters': 'dict(str, str)',
            'action_type': 'str',
            'campaign_rule_action_entities': 'DialerCampaignRuleConfigChangeCampaignRuleActionEntities',
            'additional_properties': 'object'
        }

        self.attribute_map = {
            'id': 'id',
            'parameters': 'parameters',
            'action_type': 'actionType',
            'campaign_rule_action_entities': 'campaignRuleActionEntities',
            'additional_properties': 'additionalProperties'
        }

        self._id = None
        self._parameters = None
        self._action_type = None
        self._campaign_rule_action_entities = None
        self._additional_properties = None

    @property
    def id(self):
        """
        Gets the id of this DialerCampaignRuleConfigChangeCampaignRuleAction.


        :return: The id of this DialerCampaignRuleConfigChangeCampaignRuleAction.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this DialerCampaignRuleConfigChangeCampaignRuleAction.


        :param id: The id of this DialerCampaignRuleConfigChangeCampaignRuleAction.
        :type: str
        """
        
        self._id = id

    @property
    def parameters(self):
        """
        Gets the parameters of this DialerCampaignRuleConfigChangeCampaignRuleAction.


        :return: The parameters of this DialerCampaignRuleConfigChangeCampaignRuleAction.
        :rtype: dict(str, str)
        """
        return self._parameters

    @parameters.setter
    def parameters(self, parameters):
        """
        Sets the parameters of this DialerCampaignRuleConfigChangeCampaignRuleAction.


        :param parameters: The parameters of this DialerCampaignRuleConfigChangeCampaignRuleAction.
        :type: dict(str, str)
        """
        
        self._parameters = parameters

    @property
    def action_type(self):
        """
        Gets the action_type of this DialerCampaignRuleConfigChangeCampaignRuleAction.


        :return: The action_type of this DialerCampaignRuleConfigChangeCampaignRuleAction.
        :rtype: str
        """
        return self._action_type

    @action_type.setter
    def action_type(self, action_type):
        """
        Sets the action_type of this DialerCampaignRuleConfigChangeCampaignRuleAction.


        :param action_type: The action_type of this DialerCampaignRuleConfigChangeCampaignRuleAction.
        :type: str
        """
        allowed_values = ["TURN_ON_CAMPAIGN", "TURN_OFF_CAMPAIGN", "TURN_ON_SEQUENCE", "TURN_OFF_SEQUENCE", "SET_CAMPAIGN_PRIORITY", "RECYCLE_CAMPAIGN"]
        if action_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for action_type -> " + action_type)
            self._action_type = "outdated_sdk_version"
        else:
            self._action_type = action_type

    @property
    def campaign_rule_action_entities(self):
        """
        Gets the campaign_rule_action_entities of this DialerCampaignRuleConfigChangeCampaignRuleAction.


        :return: The campaign_rule_action_entities of this DialerCampaignRuleConfigChangeCampaignRuleAction.
        :rtype: DialerCampaignRuleConfigChangeCampaignRuleActionEntities
        """
        return self._campaign_rule_action_entities

    @campaign_rule_action_entities.setter
    def campaign_rule_action_entities(self, campaign_rule_action_entities):
        """
        Sets the campaign_rule_action_entities of this DialerCampaignRuleConfigChangeCampaignRuleAction.


        :param campaign_rule_action_entities: The campaign_rule_action_entities of this DialerCampaignRuleConfigChangeCampaignRuleAction.
        :type: DialerCampaignRuleConfigChangeCampaignRuleActionEntities
        """
        
        self._campaign_rule_action_entities = campaign_rule_action_entities

    @property
    def additional_properties(self):
        """
        Gets the additional_properties of this DialerCampaignRuleConfigChangeCampaignRuleAction.


        :return: The additional_properties of this DialerCampaignRuleConfigChangeCampaignRuleAction.
        :rtype: object
        """
        return self._additional_properties

    @additional_properties.setter
    def additional_properties(self, additional_properties):
        """
        Sets the additional_properties of this DialerCampaignRuleConfigChangeCampaignRuleAction.


        :param additional_properties: The additional_properties of this DialerCampaignRuleConfigChangeCampaignRuleAction.
        :type: object
        """
        
        self._additional_properties = additional_properties

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class CallHistoryParticipant(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        CallHistoryParticipant - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'address': 'str',
            'start_time': 'datetime',
            'end_time': 'datetime',
            'purpose': 'str',
            'direction': 'str',
            'ani': 'str',
            'dnis': 'str',
            'user': 'User',
            'queue': 'Queue',
            'group': 'Group',
            'disconnect_type': 'str',
            'external_contact': 'ExternalContact',
            'external_organization': 'ExternalOrganization',
            'did_interact': 'bool',
            'sip_response_codes': 'list[int]',
            'flagged_reason': 'str',
            'outbound_campaign': 'Campaign'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'address': 'address',
            'start_time': 'startTime',
            'end_time': 'endTime',
            'purpose': 'purpose',
            'direction': 'direction',
            'ani': 'ani',
            'dnis': 'dnis',
            'user': 'user',
            'queue': 'queue',
            'group': 'group',
            'disconnect_type': 'disconnectType',
            'external_contact': 'externalContact',
            'external_organization': 'externalOrganization',
            'did_interact': 'didInteract',
            'sip_response_codes': 'sipResponseCodes',
            'flagged_reason': 'flaggedReason',
            'outbound_campaign': 'outboundCampaign'
        }

        self._id = None
        self._name = None
        self._address = None
        self._start_time = None
        self._end_time = None
        self._purpose = None
        self._direction = None
        self._ani = None
        self._dnis = None
        self._user = None
        self._queue = None
        self._group = None
        self._disconnect_type = None
        self._external_contact = None
        self._external_organization = None
        self._did_interact = None
        self._sip_response_codes = None
        self._flagged_reason = None
        self._outbound_campaign = None

    @property
    def id(self):
        """
        Gets the id of this CallHistoryParticipant.
        The unique participant ID.

        :return: The id of this CallHistoryParticipant.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this CallHistoryParticipant.
        The unique participant ID.

        :param id: The id of this CallHistoryParticipant.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this CallHistoryParticipant.
        The display friendly name of the participant.

        :return: The name of this CallHistoryParticipant.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this CallHistoryParticipant.
        The display friendly name of the participant.

        :param name: The name of this CallHistoryParticipant.
        :type: str
        """
        
        self._name = name

    @property
    def address(self):
        """
        Gets the address of this CallHistoryParticipant.
        The participant address.

        :return: The address of this CallHistoryParticipant.
        :rtype: str
        """
        return self._address

    @address.setter
    def address(self, address):
        """
        Sets the address of this CallHistoryParticipant.
        The participant address.

        :param address: The address of this CallHistoryParticipant.
        :type: str
        """
        
        self._address = address

    @property
    def start_time(self):
        """
        Gets the start_time of this CallHistoryParticipant.
        The time when this participant first joined the conversation. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The start_time of this CallHistoryParticipant.
        :rtype: datetime
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """
        Sets the start_time of this CallHistoryParticipant.
        The time when this participant first joined the conversation. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param start_time: The start_time of this CallHistoryParticipant.
        :type: datetime
        """
        
        self._start_time = start_time

    @property
    def end_time(self):
        """
        Gets the end_time of this CallHistoryParticipant.
        The time when this participant went disconnected for this media (eg: video disconnected time). Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The end_time of this CallHistoryParticipant.
        :rtype: datetime
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """
        Sets the end_time of this CallHistoryParticipant.
        The time when this participant went disconnected for this media (eg: video disconnected time). Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param end_time: The end_time of this CallHistoryParticipant.
        :type: datetime
        """
        
        self._end_time = end_time

    @property
    def purpose(self):
        """
        Gets the purpose of this CallHistoryParticipant.
        The participant's purpose.  Values can be: 'agent', 'user', 'customer', 'external', 'acd', 'ivr

        :return: The purpose of this CallHistoryParticipant.
        :rtype: str
        """
        return self._purpose

    @purpose.setter
    def purpose(self, purpose):
        """
        Sets the purpose of this CallHistoryParticipant.
        The participant's purpose.  Values can be: 'agent', 'user', 'customer', 'external', 'acd', 'ivr

        :param purpose: The purpose of this CallHistoryParticipant.
        :type: str
        """
        
        self._purpose = purpose

    @property
    def direction(self):
        """
        Gets the direction of this CallHistoryParticipant.
        The participant's direction.  Values can be: 'inbound' or 'outbound'

        :return: The direction of this CallHistoryParticipant.
        :rtype: str
        """
        return self._direction

    @direction.setter
    def direction(self, direction):
        """
        Sets the direction of this CallHistoryParticipant.
        The participant's direction.  Values can be: 'inbound' or 'outbound'

        :param direction: The direction of this CallHistoryParticipant.
        :type: str
        """
        allowed_values = ["inbound", "outbound"]
        if direction.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for direction -> " + direction)
            self._direction = "outdated_sdk_version"
        else:
            self._direction = direction

    @property
    def ani(self):
        """
        Gets the ani of this CallHistoryParticipant.
        The call ANI.

        :return: The ani of this CallHistoryParticipant.
        :rtype: str
        """
        return self._ani

    @ani.setter
    def ani(self, ani):
        """
        Sets the ani of this CallHistoryParticipant.
        The call ANI.

        :param ani: The ani of this CallHistoryParticipant.
        :type: str
        """
        
        self._ani = ani

    @property
    def dnis(self):
        """
        Gets the dnis of this CallHistoryParticipant.
        The call DNIS.

        :return: The dnis of this CallHistoryParticipant.
        :rtype: str
        """
        return self._dnis

    @dnis.setter
    def dnis(self, dnis):
        """
        Sets the dnis of this CallHistoryParticipant.
        The call DNIS.

        :param dnis: The dnis of this CallHistoryParticipant.
        :type: str
        """
        
        self._dnis = dnis

    @property
    def user(self):
        """
        Gets the user of this CallHistoryParticipant.
        The PureCloud user for this participant.

        :return: The user of this CallHistoryParticipant.
        :rtype: User
        """
        return self._user

    @user.setter
    def user(self, user):
        """
        Sets the user of this CallHistoryParticipant.
        The PureCloud user for this participant.

        :param user: The user of this CallHistoryParticipant.
        :type: User
        """
        
        self._user = user

    @property
    def queue(self):
        """
        Gets the queue of this CallHistoryParticipant.
        The PureCloud queue for this participant.

        :return: The queue of this CallHistoryParticipant.
        :rtype: Queue
        """
        return self._queue

    @queue.setter
    def queue(self, queue):
        """
        Sets the queue of this CallHistoryParticipant.
        The PureCloud queue for this participant.

        :param queue: The queue of this CallHistoryParticipant.
        :type: Queue
        """
        
        self._queue = queue

    @property
    def group(self):
        """
        Gets the group of this CallHistoryParticipant.
        The group involved in the group ring call.

        :return: The group of this CallHistoryParticipant.
        :rtype: Group
        """
        return self._group

    @group.setter
    def group(self, group):
        """
        Sets the group of this CallHistoryParticipant.
        The group involved in the group ring call.

        :param group: The group of this CallHistoryParticipant.
        :type: Group
        """
        
        self._group = group

    @property
    def disconnect_type(self):
        """
        Gets the disconnect_type of this CallHistoryParticipant.
        The reason the participant was disconnected from the conversation.

        :return: The disconnect_type of this CallHistoryParticipant.
        :rtype: str
        """
        return self._disconnect_type

    @disconnect_type.setter
    def disconnect_type(self, disconnect_type):
        """
        Sets the disconnect_type of this CallHistoryParticipant.
        The reason the participant was disconnected from the conversation.

        :param disconnect_type: The disconnect_type of this CallHistoryParticipant.
        :type: str
        """
        allowed_values = ["endpoint", "client", "system", "transfer", "transfer.conference", "transfer.consult", "transfer.forward", "transfer.noanswer", "transfer.notavailable", "transport.failure", "error", "peer", "other", "spam"]
        if disconnect_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for disconnect_type -> " + disconnect_type)
            self._disconnect_type = "outdated_sdk_version"
        else:
            self._disconnect_type = disconnect_type

    @property
    def external_contact(self):
        """
        Gets the external_contact of this CallHistoryParticipant.
        The PureCloud external contact

        :return: The external_contact of this CallHistoryParticipant.
        :rtype: ExternalContact
        """
        return self._external_contact

    @external_contact.setter
    def external_contact(self, external_contact):
        """
        Sets the external_contact of this CallHistoryParticipant.
        The PureCloud external contact

        :param external_contact: The external_contact of this CallHistoryParticipant.
        :type: ExternalContact
        """
        
        self._external_contact = external_contact

    @property
    def external_organization(self):
        """
        Gets the external_organization of this CallHistoryParticipant.
        The PureCloud external organization

        :return: The external_organization of this CallHistoryParticipant.
        :rtype: ExternalOrganization
        """
        return self._external_organization

    @external_organization.setter
    def external_organization(self, external_organization):
        """
        Sets the external_organization of this CallHistoryParticipant.
        The PureCloud external organization

        :param external_organization: The external_organization of this CallHistoryParticipant.
        :type: ExternalOrganization
        """
        
        self._external_organization = external_organization

    @property
    def did_interact(self):
        """
        Gets the did_interact of this CallHistoryParticipant.
        Indicates whether the contact ever connected

        :return: The did_interact of this CallHistoryParticipant.
        :rtype: bool
        """
        return self._did_interact

    @did_interact.setter
    def did_interact(self, did_interact):
        """
        Sets the did_interact of this CallHistoryParticipant.
        Indicates whether the contact ever connected

        :param did_interact: The did_interact of this CallHistoryParticipant.
        :type: bool
        """
        
        self._did_interact = did_interact

    @property
    def sip_response_codes(self):
        """
        Gets the sip_response_codes of this CallHistoryParticipant.
        Indicates SIP Response codes associated with the participant

        :return: The sip_response_codes of this CallHistoryParticipant.
        :rtype: list[int]
        """
        return self._sip_response_codes

    @sip_response_codes.setter
    def sip_response_codes(self, sip_response_codes):
        """
        Sets the sip_response_codes of this CallHistoryParticipant.
        Indicates SIP Response codes associated with the participant

        :param sip_response_codes: The sip_response_codes of this CallHistoryParticipant.
        :type: list[int]
        """
        
        self._sip_response_codes = sip_response_codes

    @property
    def flagged_reason(self):
        """
        Gets the flagged_reason of this CallHistoryParticipant.
        The reason specifying why participant flagged the conversation.

        :return: The flagged_reason of this CallHistoryParticipant.
        :rtype: str
        """
        return self._flagged_reason

    @flagged_reason.setter
    def flagged_reason(self, flagged_reason):
        """
        Sets the flagged_reason of this CallHistoryParticipant.
        The reason specifying why participant flagged the conversation.

        :param flagged_reason: The flagged_reason of this CallHistoryParticipant.
        :type: str
        """
        allowed_values = ["general"]
        if flagged_reason.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for flagged_reason -> " + flagged_reason)
            self._flagged_reason = "outdated_sdk_version"
        else:
            self._flagged_reason = flagged_reason

    @property
    def outbound_campaign(self):
        """
        Gets the outbound_campaign of this CallHistoryParticipant.
        The outbound campaign associated with the participant

        :return: The outbound_campaign of this CallHistoryParticipant.
        :rtype: Campaign
        """
        return self._outbound_campaign

    @outbound_campaign.setter
    def outbound_campaign(self, outbound_campaign):
        """
        Sets the outbound_campaign of this CallHistoryParticipant.
        The outbound campaign associated with the participant

        :param outbound_campaign: The outbound_campaign of this CallHistoryParticipant.
        :type: Campaign
        """
        
        self._outbound_campaign = outbound_campaign

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class Annotation(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        Annotation - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'type': 'str',
            'location': 'int',
            'duration_ms': 'int',
            'absolute_location': 'int',
            'absolute_duration_ms': 'int',
            'recording_location': 'int',
            'recording_duration_ms': 'int',
            'user': 'User',
            'description': 'str',
            'keyword_name': 'str',
            'confidence': 'float',
            'keyword_set_id': 'str',
            'keyword_set_name': 'str',
            'utterance': 'str',
            'time_begin': 'str',
            'time_end': 'str',
            'keyword_confidence_threshold': 'str',
            'agent_score_modifier': 'str',
            'customer_score_modifier': 'str',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'type': 'type',
            'location': 'location',
            'duration_ms': 'durationMs',
            'absolute_location': 'absoluteLocation',
            'absolute_duration_ms': 'absoluteDurationMs',
            'recording_location': 'recordingLocation',
            'recording_duration_ms': 'recordingDurationMs',
            'user': 'user',
            'description': 'description',
            'keyword_name': 'keywordName',
            'confidence': 'confidence',
            'keyword_set_id': 'keywordSetId',
            'keyword_set_name': 'keywordSetName',
            'utterance': 'utterance',
            'time_begin': 'timeBegin',
            'time_end': 'timeEnd',
            'keyword_confidence_threshold': 'keywordConfidenceThreshold',
            'agent_score_modifier': 'agentScoreModifier',
            'customer_score_modifier': 'customerScoreModifier',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._type = None
        self._location = None
        self._duration_ms = None
        self._absolute_location = None
        self._absolute_duration_ms = None
        self._recording_location = None
        self._recording_duration_ms = None
        self._user = None
        self._description = None
        self._keyword_name = None
        self._confidence = None
        self._keyword_set_id = None
        self._keyword_set_name = None
        self._utterance = None
        self._time_begin = None
        self._time_end = None
        self._keyword_confidence_threshold = None
        self._agent_score_modifier = None
        self._customer_score_modifier = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this Annotation.
        The globally unique identifier for the object.

        :return: The id of this Annotation.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Annotation.
        The globally unique identifier for the object.

        :param id: The id of this Annotation.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this Annotation.


        :return: The name of this Annotation.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Annotation.


        :param name: The name of this Annotation.
        :type: str
        """
        
        self._name = name

    @property
    def type(self):
        """
        Gets the type of this Annotation.


        :return: The type of this Annotation.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this Annotation.


        :param type: The type of this Annotation.
        :type: str
        """
        
        self._type = type

    @property
    def location(self):
        """
        Gets the location of this Annotation.
        Offset of annotation in milliseconds.

        :return: The location of this Annotation.
        :rtype: int
        """
        return self._location

    @location.setter
    def location(self, location):
        """
        Sets the location of this Annotation.
        Offset of annotation in milliseconds.

        :param location: The location of this Annotation.
        :type: int
        """
        
        self._location = location

    @property
    def duration_ms(self):
        """
        Gets the duration_ms of this Annotation.
        Duration of annotation in milliseconds.

        :return: The duration_ms of this Annotation.
        :rtype: int
        """
        return self._duration_ms

    @duration_ms.setter
    def duration_ms(self, duration_ms):
        """
        Sets the duration_ms of this Annotation.
        Duration of annotation in milliseconds.

        :param duration_ms: The duration_ms of this Annotation.
        :type: int
        """
        
        self._duration_ms = duration_ms

    @property
    def absolute_location(self):
        """
        Gets the absolute_location of this Annotation.
        Offset of annotation (milliseconds) from start of recording.

        :return: The absolute_location of this Annotation.
        :rtype: int
        """
        return self._absolute_location

    @absolute_location.setter
    def absolute_location(self, absolute_location):
        """
        Sets the absolute_location of this Annotation.
        Offset of annotation (milliseconds) from start of recording.

        :param absolute_location: The absolute_location of this Annotation.
        :type: int
        """
        
        self._absolute_location = absolute_location

    @property
    def absolute_duration_ms(self):
        """
        Gets the absolute_duration_ms of this Annotation.
        Duration of annotation (milliseconds).

        :return: The absolute_duration_ms of this Annotation.
        :rtype: int
        """
        return self._absolute_duration_ms

    @absolute_duration_ms.setter
    def absolute_duration_ms(self, absolute_duration_ms):
        """
        Sets the absolute_duration_ms of this Annotation.
        Duration of annotation (milliseconds).

        :param absolute_duration_ms: The absolute_duration_ms of this Annotation.
        :type: int
        """
        
        self._absolute_duration_ms = absolute_duration_ms

    @property
    def recording_location(self):
        """
        Gets the recording_location of this Annotation.
        Offset of annotation (milliseconds) from start of recording, adjusted for any recording cuts

        :return: The recording_location of this Annotation.
        :rtype: int
        """
        return self._recording_location

    @recording_location.setter
    def recording_location(self, recording_location):
        """
        Sets the recording_location of this Annotation.
        Offset of annotation (milliseconds) from start of recording, adjusted for any recording cuts

        :param recording_location: The recording_location of this Annotation.
        :type: int
        """
        
        self._recording_location = recording_location

    @property
    def recording_duration_ms(self):
        """
        Gets the recording_duration_ms of this Annotation.
        Duration of annotation (milliseconds), adjusted for any recording cuts.

        :return: The recording_duration_ms of this Annotation.
        :rtype: int
        """
        return self._recording_duration_ms

    @recording_duration_ms.setter
    def recording_duration_ms(self, recording_duration_ms):
        """
        Sets the recording_duration_ms of this Annotation.
        Duration of annotation (milliseconds), adjusted for any recording cuts.

        :param recording_duration_ms: The recording_duration_ms of this Annotation.
        :type: int
        """
        
        self._recording_duration_ms = recording_duration_ms

    @property
    def user(self):
        """
        Gets the user of this Annotation.
        User that created this annotation (if any).

        :return: The user of this Annotation.
        :rtype: User
        """
        return self._user

    @user.setter
    def user(self, user):
        """
        Sets the user of this Annotation.
        User that created this annotation (if any).

        :param user: The user of this Annotation.
        :type: User
        """
        
        self._user = user

    @property
    def description(self):
        """
        Gets the description of this Annotation.
        Text of annotation.

        :return: The description of this Annotation.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this Annotation.
        Text of annotation.

        :param description: The description of this Annotation.
        :type: str
        """
        
        self._description = description

    @property
    def keyword_name(self):
        """
        Gets the keyword_name of this Annotation.
        The word or phrase which is being looked for with speech recognition.

        :return: The keyword_name of this Annotation.
        :rtype: str
        """
        return self._keyword_name

    @keyword_name.setter
    def keyword_name(self, keyword_name):
        """
        Sets the keyword_name of this Annotation.
        The word or phrase which is being looked for with speech recognition.

        :param keyword_name: The keyword_name of this Annotation.
        :type: str
        """
        
        self._keyword_name = keyword_name

    @property
    def confidence(self):
        """
        Gets the confidence of this Annotation.
        Actual confidence that this is an accurate match.

        :return: The confidence of this Annotation.
        :rtype: float
        """
        return self._confidence

    @confidence.setter
    def confidence(self, confidence):
        """
        Sets the confidence of this Annotation.
        Actual confidence that this is an accurate match.

        :param confidence: The confidence of this Annotation.
        :type: float
        """
        
        self._confidence = confidence

    @property
    def keyword_set_id(self):
        """
        Gets the keyword_set_id of this Annotation.
        A unique identifier for the keyword set to which this spotted keyword belongs.

        :return: The keyword_set_id of this Annotation.
        :rtype: str
        """
        return self._keyword_set_id

    @keyword_set_id.setter
    def keyword_set_id(self, keyword_set_id):
        """
        Sets the keyword_set_id of this Annotation.
        A unique identifier for the keyword set to which this spotted keyword belongs.

        :param keyword_set_id: The keyword_set_id of this Annotation.
        :type: str
        """
        
        self._keyword_set_id = keyword_set_id

    @property
    def keyword_set_name(self):
        """
        Gets the keyword_set_name of this Annotation.
        The keyword set to which this spotted keyword belongs.

        :return: The keyword_set_name of this Annotation.
        :rtype: str
        """
        return self._keyword_set_name

    @keyword_set_name.setter
    def keyword_set_name(self, keyword_set_name):
        """
        Sets the keyword_set_name of this Annotation.
        The keyword set to which this spotted keyword belongs.

        :param keyword_set_name: The keyword_set_name of this Annotation.
        :type: str
        """
        
        self._keyword_set_name = keyword_set_name

    @property
    def utterance(self):
        """
        Gets the utterance of this Annotation.
        The phonetic spellings for the phrase and alternate spellings.

        :return: The utterance of this Annotation.
        :rtype: str
        """
        return self._utterance

    @utterance.setter
    def utterance(self, utterance):
        """
        Sets the utterance of this Annotation.
        The phonetic spellings for the phrase and alternate spellings.

        :param utterance: The utterance of this Annotation.
        :type: str
        """
        
        self._utterance = utterance

    @property
    def time_begin(self):
        """
        Gets the time_begin of this Annotation.
        Beginning time offset of the keyword spot match.

        :return: The time_begin of this Annotation.
        :rtype: str
        """
        return self._time_begin

    @time_begin.setter
    def time_begin(self, time_begin):
        """
        Sets the time_begin of this Annotation.
        Beginning time offset of the keyword spot match.

        :param time_begin: The time_begin of this Annotation.
        :type: str
        """
        
        self._time_begin = time_begin

    @property
    def time_end(self):
        """
        Gets the time_end of this Annotation.
        Ending time offset of the keyword spot match.

        :return: The time_end of this Annotation.
        :rtype: str
        """
        return self._time_end

    @time_end.setter
    def time_end(self, time_end):
        """
        Sets the time_end of this Annotation.
        Ending time offset of the keyword spot match.

        :param time_end: The time_end of this Annotation.
        :type: str
        """
        
        self._time_end = time_end

    @property
    def keyword_confidence_threshold(self):
        """
        Gets the keyword_confidence_threshold of this Annotation.
        Configured sensitivity threshold that can be increased to lower false positives or decreased to reduce false negatives.

        :return: The keyword_confidence_threshold of this Annotation.
        :rtype: str
        """
        return self._keyword_confidence_threshold

    @keyword_confidence_threshold.setter
    def keyword_confidence_threshold(self, keyword_confidence_threshold):
        """
        Sets the keyword_confidence_threshold of this Annotation.
        Configured sensitivity threshold that can be increased to lower false positives or decreased to reduce false negatives.

        :param keyword_confidence_threshold: The keyword_confidence_threshold of this Annotation.
        :type: str
        """
        
        self._keyword_confidence_threshold = keyword_confidence_threshold

    @property
    def agent_score_modifier(self):
        """
        Gets the agent_score_modifier of this Annotation.
        A modifier to the evaluation score when the phrase is spotted in the agent channel.

        :return: The agent_score_modifier of this Annotation.
        :rtype: str
        """
        return self._agent_score_modifier

    @agent_score_modifier.setter
    def agent_score_modifier(self, agent_score_modifier):
        """
        Sets the agent_score_modifier of this Annotation.
        A modifier to the evaluation score when the phrase is spotted in the agent channel.

        :param agent_score_modifier: The agent_score_modifier of this Annotation.
        :type: str
        """
        
        self._agent_score_modifier = agent_score_modifier

    @property
    def customer_score_modifier(self):
        """
        Gets the customer_score_modifier of this Annotation.
        A modifier to the evaluation score when the phrase is spotted in the customer channel.

        :return: The customer_score_modifier of this Annotation.
        :rtype: str
        """
        return self._customer_score_modifier

    @customer_score_modifier.setter
    def customer_score_modifier(self, customer_score_modifier):
        """
        Sets the customer_score_modifier of this Annotation.
        A modifier to the evaluation score when the phrase is spotted in the customer channel.

        :param customer_score_modifier: The customer_score_modifier of this Annotation.
        :type: str
        """
        
        self._customer_score_modifier = customer_score_modifier

    @property
    def self_uri(self):
        """
        Gets the self_uri of this Annotation.
        The URI for this object

        :return: The self_uri of this Annotation.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this Annotation.
        The URI for this object

        :param self_uri: The self_uri of this Annotation.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class ConversationEventTopicCallback(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        ConversationEventTopicCallback - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'state': 'str',
            'id': 'str',
            'direction': 'str',
            'held': 'bool',
            'disconnect_type': 'str',
            'start_hold_time': 'datetime',
            'dialer_preview': 'ConversationEventTopicDialerPreview',
            'voicemail': 'ConversationEventTopicVoicemail',
            'callback_numbers': 'list[str]',
            'callback_user_name': 'str',
            'script_id': 'str',
            'peer_id': 'str',
            'external_campaign': 'bool',
            'skip_enabled': 'bool',
            'provider': 'str',
            'timeout_seconds': 'int',
            'connected_time': 'datetime',
            'disconnected_time': 'datetime',
            'callback_scheduled_time': 'datetime',
            'automated_callback_config_id': 'str',
            'wrapup': 'ConversationEventTopicWrapup',
            'after_call_work': 'ConversationEventTopicAfterCallWork',
            'after_call_work_required': 'bool',
            'additional_properties': 'object'
        }

        self.attribute_map = {
            'state': 'state',
            'id': 'id',
            'direction': 'direction',
            'held': 'held',
            'disconnect_type': 'disconnectType',
            'start_hold_time': 'startHoldTime',
            'dialer_preview': 'dialerPreview',
            'voicemail': 'voicemail',
            'callback_numbers': 'callbackNumbers',
            'callback_user_name': 'callbackUserName',
            'script_id': 'scriptId',
            'peer_id': 'peerId',
            'external_campaign': 'externalCampaign',
            'skip_enabled': 'skipEnabled',
            'provider': 'provider',
            'timeout_seconds': 'timeoutSeconds',
            'connected_time': 'connectedTime',
            'disconnected_time': 'disconnectedTime',
            'callback_scheduled_time': 'callbackScheduledTime',
            'automated_callback_config_id': 'automatedCallbackConfigId',
            'wrapup': 'wrapup',
            'after_call_work': 'afterCallWork',
            'after_call_work_required': 'afterCallWorkRequired',
            'additional_properties': 'additionalProperties'
        }

        self._state = None
        self._id = None
        self._direction = None
        self._held = None
        self._disconnect_type = None
        self._start_hold_time = None
        self._dialer_preview = None
        self._voicemail = None
        self._callback_numbers = None
        self._callback_user_name = None
        self._script_id = None
        self._peer_id = None
        self._external_campaign = None
        self._skip_enabled = None
        self._provider = None
        self._timeout_seconds = None
        self._connected_time = None
        self._disconnected_time = None
        self._callback_scheduled_time = None
        self._automated_callback_config_id = None
        self._wrapup = None
        self._after_call_work = None
        self._after_call_work_required = None
        self._additional_properties = None

    @property
    def state(self):
        """
        Gets the state of this ConversationEventTopicCallback.


        :return: The state of this ConversationEventTopicCallback.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this ConversationEventTopicCallback.


        :param state: The state of this ConversationEventTopicCallback.
        :type: str
        """
        allowed_values = ["ALERTING", "DIALING", "CONTACTING", "OFFERING", "CONNECTED", "DISCONNECTED", "TERMINATED", "SCHEDULED", "UPLOADING", "NONE"]
        if state.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for state -> " + state)
            self._state = "outdated_sdk_version"
        else:
            self._state = state

    @property
    def id(self):
        """
        Gets the id of this ConversationEventTopicCallback.


        :return: The id of this ConversationEventTopicCallback.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ConversationEventTopicCallback.


        :param id: The id of this ConversationEventTopicCallback.
        :type: str
        """
        
        self._id = id

    @property
    def direction(self):
        """
        Gets the direction of this ConversationEventTopicCallback.


        :return: The direction of this ConversationEventTopicCallback.
        :rtype: str
        """
        return self._direction

    @direction.setter
    def direction(self, direction):
        """
        Sets the direction of this ConversationEventTopicCallback.


        :param direction: The direction of this ConversationEventTopicCallback.
        :type: str
        """
        allowed_values = ["INBOUND", "OUTBOUND"]
        if direction.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for direction -> " + direction)
            self._direction = "outdated_sdk_version"
        else:
            self._direction = direction

    @property
    def held(self):
        """
        Gets the held of this ConversationEventTopicCallback.


        :return: The held of this ConversationEventTopicCallback.
        :rtype: bool
        """
        return self._held

    @held.setter
    def held(self, held):
        """
        Sets the held of this ConversationEventTopicCallback.


        :param held: The held of this ConversationEventTopicCallback.
        :type: bool
        """
        
        self._held = held

    @property
    def disconnect_type(self):
        """
        Gets the disconnect_type of this ConversationEventTopicCallback.


        :return: The disconnect_type of this ConversationEventTopicCallback.
        :rtype: str
        """
        return self._disconnect_type

    @disconnect_type.setter
    def disconnect_type(self, disconnect_type):
        """
        Sets the disconnect_type of this ConversationEventTopicCallback.


        :param disconnect_type: The disconnect_type of this ConversationEventTopicCallback.
        :type: str
        """
        allowed_values = ["ENDPOINT", "CLIENT", "SYSTEM", "TIMEOUT", "TRANSFER", "TRANSFER_CONFERENCE", "TRANSFER_CONSULT", "TRANSFER_NOANSWER", "TRANSFER_NOTAVAILABLE", "TRANSFER_FORWARD", "TRANSPORT_FAILURE", "ERROR", "PEER", "OTHER", "SPAM", "UNCALLABLE"]
        if disconnect_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for disconnect_type -> " + disconnect_type)
            self._disconnect_type = "outdated_sdk_version"
        else:
            self._disconnect_type = disconnect_type

    @property
    def start_hold_time(self):
        """
        Gets the start_hold_time of this ConversationEventTopicCallback.


        :return: The start_hold_time of this ConversationEventTopicCallback.
        :rtype: datetime
        """
        return self._start_hold_time

    @start_hold_time.setter
    def start_hold_time(self, start_hold_time):
        """
        Sets the start_hold_time of this ConversationEventTopicCallback.


        :param start_hold_time: The start_hold_time of this ConversationEventTopicCallback.
        :type: datetime
        """
        
        self._start_hold_time = start_hold_time

    @property
    def dialer_preview(self):
        """
        Gets the dialer_preview of this ConversationEventTopicCallback.


        :return: The dialer_preview of this ConversationEventTopicCallback.
        :rtype: ConversationEventTopicDialerPreview
        """
        return self._dialer_preview

    @dialer_preview.setter
    def dialer_preview(self, dialer_preview):
        """
        Sets the dialer_preview of this ConversationEventTopicCallback.


        :param dialer_preview: The dialer_preview of this ConversationEventTopicCallback.
        :type: ConversationEventTopicDialerPreview
        """
        
        self._dialer_preview = dialer_preview

    @property
    def voicemail(self):
        """
        Gets the voicemail of this ConversationEventTopicCallback.


        :return: The voicemail of this ConversationEventTopicCallback.
        :rtype: ConversationEventTopicVoicemail
        """
        return self._voicemail

    @voicemail.setter
    def voicemail(self, voicemail):
        """
        Sets the voicemail of this ConversationEventTopicCallback.


        :param voicemail: The voicemail of this ConversationEventTopicCallback.
        :type: ConversationEventTopicVoicemail
        """
        
        self._voicemail = voicemail

    @property
    def callback_numbers(self):
        """
        Gets the callback_numbers of this ConversationEventTopicCallback.


        :return: The callback_numbers of this ConversationEventTopicCallback.
        :rtype: list[str]
        """
        return self._callback_numbers

    @callback_numbers.setter
    def callback_numbers(self, callback_numbers):
        """
        Sets the callback_numbers of this ConversationEventTopicCallback.


        :param callback_numbers: The callback_numbers of this ConversationEventTopicCallback.
        :type: list[str]
        """
        
        self._callback_numbers = callback_numbers

    @property
    def callback_user_name(self):
        """
        Gets the callback_user_name of this ConversationEventTopicCallback.


        :return: The callback_user_name of this ConversationEventTopicCallback.
        :rtype: str
        """
        return self._callback_user_name

    @callback_user_name.setter
    def callback_user_name(self, callback_user_name):
        """
        Sets the callback_user_name of this ConversationEventTopicCallback.


        :param callback_user_name: The callback_user_name of this ConversationEventTopicCallback.
        :type: str
        """
        
        self._callback_user_name = callback_user_name

    @property
    def script_id(self):
        """
        Gets the script_id of this ConversationEventTopicCallback.


        :return: The script_id of this ConversationEventTopicCallback.
        :rtype: str
        """
        return self._script_id

    @script_id.setter
    def script_id(self, script_id):
        """
        Sets the script_id of this ConversationEventTopicCallback.


        :param script_id: The script_id of this ConversationEventTopicCallback.
        :type: str
        """
        
        self._script_id = script_id

    @property
    def peer_id(self):
        """
        Gets the peer_id of this ConversationEventTopicCallback.


        :return: The peer_id of this ConversationEventTopicCallback.
        :rtype: str
        """
        return self._peer_id

    @peer_id.setter
    def peer_id(self, peer_id):
        """
        Sets the peer_id of this ConversationEventTopicCallback.


        :param peer_id: The peer_id of this ConversationEventTopicCallback.
        :type: str
        """
        
        self._peer_id = peer_id

    @property
    def external_campaign(self):
        """
        Gets the external_campaign of this ConversationEventTopicCallback.


        :return: The external_campaign of this ConversationEventTopicCallback.
        :rtype: bool
        """
        return self._external_campaign

    @external_campaign.setter
    def external_campaign(self, external_campaign):
        """
        Sets the external_campaign of this ConversationEventTopicCallback.


        :param external_campaign: The external_campaign of this ConversationEventTopicCallback.
        :type: bool
        """
        
        self._external_campaign = external_campaign

    @property
    def skip_enabled(self):
        """
        Gets the skip_enabled of this ConversationEventTopicCallback.


        :return: The skip_enabled of this ConversationEventTopicCallback.
        :rtype: bool
        """
        return self._skip_enabled

    @skip_enabled.setter
    def skip_enabled(self, skip_enabled):
        """
        Sets the skip_enabled of this ConversationEventTopicCallback.


        :param skip_enabled: The skip_enabled of this ConversationEventTopicCallback.
        :type: bool
        """
        
        self._skip_enabled = skip_enabled

    @property
    def provider(self):
        """
        Gets the provider of this ConversationEventTopicCallback.


        :return: The provider of this ConversationEventTopicCallback.
        :rtype: str
        """
        return self._provider

    @provider.setter
    def provider(self, provider):
        """
        Sets the provider of this ConversationEventTopicCallback.


        :param provider: The provider of this ConversationEventTopicCallback.
        :type: str
        """
        
        self._provider = provider

    @property
    def timeout_seconds(self):
        """
        Gets the timeout_seconds of this ConversationEventTopicCallback.


        :return: The timeout_seconds of this ConversationEventTopicCallback.
        :rtype: int
        """
        return self._timeout_seconds

    @timeout_seconds.setter
    def timeout_seconds(self, timeout_seconds):
        """
        Sets the timeout_seconds of this ConversationEventTopicCallback.


        :param timeout_seconds: The timeout_seconds of this ConversationEventTopicCallback.
        :type: int
        """
        
        self._timeout_seconds = timeout_seconds

    @property
    def connected_time(self):
        """
        Gets the connected_time of this ConversationEventTopicCallback.


        :return: The connected_time of this ConversationEventTopicCallback.
        :rtype: datetime
        """
        return self._connected_time

    @connected_time.setter
    def connected_time(self, connected_time):
        """
        Sets the connected_time of this ConversationEventTopicCallback.


        :param connected_time: The connected_time of this ConversationEventTopicCallback.
        :type: datetime
        """
        
        self._connected_time = connected_time

    @property
    def disconnected_time(self):
        """
        Gets the disconnected_time of this ConversationEventTopicCallback.


        :return: The disconnected_time of this ConversationEventTopicCallback.
        :rtype: datetime
        """
        return self._disconnected_time

    @disconnected_time.setter
    def disconnected_time(self, disconnected_time):
        """
        Sets the disconnected_time of this ConversationEventTopicCallback.


        :param disconnected_time: The disconnected_time of this ConversationEventTopicCallback.
        :type: datetime
        """
        
        self._disconnected_time = disconnected_time

    @property
    def callback_scheduled_time(self):
        """
        Gets the callback_scheduled_time of this ConversationEventTopicCallback.


        :return: The callback_scheduled_time of this ConversationEventTopicCallback.
        :rtype: datetime
        """
        return self._callback_scheduled_time

    @callback_scheduled_time.setter
    def callback_scheduled_time(self, callback_scheduled_time):
        """
        Sets the callback_scheduled_time of this ConversationEventTopicCallback.


        :param callback_scheduled_time: The callback_scheduled_time of this ConversationEventTopicCallback.
        :type: datetime
        """
        
        self._callback_scheduled_time = callback_scheduled_time

    @property
    def automated_callback_config_id(self):
        """
        Gets the automated_callback_config_id of this ConversationEventTopicCallback.


        :return: The automated_callback_config_id of this ConversationEventTopicCallback.
        :rtype: str
        """
        return self._automated_callback_config_id

    @automated_callback_config_id.setter
    def automated_callback_config_id(self, automated_callback_config_id):
        """
        Sets the automated_callback_config_id of this ConversationEventTopicCallback.


        :param automated_callback_config_id: The automated_callback_config_id of this ConversationEventTopicCallback.
        :type: str
        """
        
        self._automated_callback_config_id = automated_callback_config_id

    @property
    def wrapup(self):
        """
        Gets the wrapup of this ConversationEventTopicCallback.


        :return: The wrapup of this ConversationEventTopicCallback.
        :rtype: ConversationEventTopicWrapup
        """
        return self._wrapup

    @wrapup.setter
    def wrapup(self, wrapup):
        """
        Sets the wrapup of this ConversationEventTopicCallback.


        :param wrapup: The wrapup of this ConversationEventTopicCallback.
        :type: ConversationEventTopicWrapup
        """
        
        self._wrapup = wrapup

    @property
    def after_call_work(self):
        """
        Gets the after_call_work of this ConversationEventTopicCallback.


        :return: The after_call_work of this ConversationEventTopicCallback.
        :rtype: ConversationEventTopicAfterCallWork
        """
        return self._after_call_work

    @after_call_work.setter
    def after_call_work(self, after_call_work):
        """
        Sets the after_call_work of this ConversationEventTopicCallback.


        :param after_call_work: The after_call_work of this ConversationEventTopicCallback.
        :type: ConversationEventTopicAfterCallWork
        """
        
        self._after_call_work = after_call_work

    @property
    def after_call_work_required(self):
        """
        Gets the after_call_work_required of this ConversationEventTopicCallback.


        :return: The after_call_work_required of this ConversationEventTopicCallback.
        :rtype: bool
        """
        return self._after_call_work_required

    @after_call_work_required.setter
    def after_call_work_required(self, after_call_work_required):
        """
        Sets the after_call_work_required of this ConversationEventTopicCallback.


        :param after_call_work_required: The after_call_work_required of this ConversationEventTopicCallback.
        :type: bool
        """
        
        self._after_call_work_required = after_call_work_required

    @property
    def additional_properties(self):
        """
        Gets the additional_properties of this ConversationEventTopicCallback.


        :return: The additional_properties of this ConversationEventTopicCallback.
        :rtype: object
        """
        return self._additional_properties

    @additional_properties.setter
    def additional_properties(self, additional_properties):
        """
        Sets the additional_properties of this ConversationEventTopicCallback.


        :param additional_properties: The additional_properties of this ConversationEventTopicCallback.
        :type: object
        """
        
        self._additional_properties = additional_properties

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class ChatMessage(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        ChatMessage - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'body': 'str',
            'id': 'str',
            'to': 'str',
            'pcFrom': 'str',
            'utc': 'str',
            'chat': 'str',
            'message': 'str',
            'type': 'str',
            'body_type': 'str',
            'sender_communication_id': 'str',
            'participant_purpose': 'str',
            'user': 'ChatMessageUser'
        }

        self.attribute_map = {
            'body': 'body',
            'id': 'id',
            'to': 'to',
            'pcFrom': 'from',
            'utc': 'utc',
            'chat': 'chat',
            'message': 'message',
            'type': 'type',
            'body_type': 'bodyType',
            'sender_communication_id': 'senderCommunicationId',
            'participant_purpose': 'participantPurpose',
            'user': 'user'
        }

        self._body = None
        self._id = None
        self._to = None
        self._pcFrom = None
        self._utc = None
        self._chat = None
        self._message = None
        self._type = None
        self._body_type = None
        self._sender_communication_id = None
        self._participant_purpose = None
        self._user = None

    @property
    def body(self):
        """
        Gets the body of this ChatMessage.
        The message body

        :return: The body of this ChatMessage.
        :rtype: str
        """
        return self._body

    @body.setter
    def body(self, body):
        """
        Sets the body of this ChatMessage.
        The message body

        :param body: The body of this ChatMessage.
        :type: str
        """
        
        self._body = body

    @property
    def id(self):
        """
        Gets the id of this ChatMessage.


        :return: The id of this ChatMessage.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ChatMessage.


        :param id: The id of this ChatMessage.
        :type: str
        """
        
        self._id = id

    @property
    def to(self):
        """
        Gets the to of this ChatMessage.
        The message recipient

        :return: The to of this ChatMessage.
        :rtype: str
        """
        return self._to

    @to.setter
    def to(self, to):
        """
        Sets the to of this ChatMessage.
        The message recipient

        :param to: The to of this ChatMessage.
        :type: str
        """
        
        self._to = to

    @property
    def pcFrom(self):
        """
        Gets the pcFrom of this ChatMessage.
        The message sender

        :return: The pcFrom of this ChatMessage.
        :rtype: str
        """
        return self._pcFrom

    @pcFrom.setter
    def pcFrom(self, pcFrom):
        """
        Sets the pcFrom of this ChatMessage.
        The message sender

        :param pcFrom: The pcFrom of this ChatMessage.
        :type: str
        """
        
        self._pcFrom = pcFrom

    @property
    def utc(self):
        """
        Gets the utc of this ChatMessage.


        :return: The utc of this ChatMessage.
        :rtype: str
        """
        return self._utc

    @utc.setter
    def utc(self, utc):
        """
        Sets the utc of this ChatMessage.


        :param utc: The utc of this ChatMessage.
        :type: str
        """
        
        self._utc = utc

    @property
    def chat(self):
        """
        Gets the chat of this ChatMessage.
        The interaction id (if available)

        :return: The chat of this ChatMessage.
        :rtype: str
        """
        return self._chat

    @chat.setter
    def chat(self, chat):
        """
        Sets the chat of this ChatMessage.
        The interaction id (if available)

        :param chat: The chat of this ChatMessage.
        :type: str
        """
        
        self._chat = chat

    @property
    def message(self):
        """
        Gets the message of this ChatMessage.
        The message id

        :return: The message of this ChatMessage.
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """
        Sets the message of this ChatMessage.
        The message id

        :param message: The message of this ChatMessage.
        :type: str
        """
        
        self._message = message

    @property
    def type(self):
        """
        Gets the type of this ChatMessage.


        :return: The type of this ChatMessage.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this ChatMessage.


        :param type: The type of this ChatMessage.
        :type: str
        """
        
        self._type = type

    @property
    def body_type(self):
        """
        Gets the body_type of this ChatMessage.
        Type of the message body (v2 chats only)

        :return: The body_type of this ChatMessage.
        :rtype: str
        """
        return self._body_type

    @body_type.setter
    def body_type(self, body_type):
        """
        Sets the body_type of this ChatMessage.
        Type of the message body (v2 chats only)

        :param body_type: The body_type of this ChatMessage.
        :type: str
        """
        allowed_values = ["STANDARD", "ACTIVITY", "TYPING", "NOTICE", "MEMBERJOIN", "MEMBERLEAVE", "MEDIAREQUEST"]
        if body_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for body_type -> " + body_type)
            self._body_type = "outdated_sdk_version"
        else:
            self._body_type = body_type

    @property
    def sender_communication_id(self):
        """
        Gets the sender_communication_id of this ChatMessage.
        Communication of sender (v2 chats only)

        :return: The sender_communication_id of this ChatMessage.
        :rtype: str
        """
        return self._sender_communication_id

    @sender_communication_id.setter
    def sender_communication_id(self, sender_communication_id):
        """
        Sets the sender_communication_id of this ChatMessage.
        Communication of sender (v2 chats only)

        :param sender_communication_id: The sender_communication_id of this ChatMessage.
        :type: str
        """
        
        self._sender_communication_id = sender_communication_id

    @property
    def participant_purpose(self):
        """
        Gets the participant_purpose of this ChatMessage.
        Participant purpose of sender (v2 chats only)

        :return: The participant_purpose of this ChatMessage.
        :rtype: str
        """
        return self._participant_purpose

    @participant_purpose.setter
    def participant_purpose(self, participant_purpose):
        """
        Sets the participant_purpose of this ChatMessage.
        Participant purpose of sender (v2 chats only)

        :param participant_purpose: The participant_purpose of this ChatMessage.
        :type: str
        """
        
        self._participant_purpose = participant_purpose

    @property
    def user(self):
        """
        Gets the user of this ChatMessage.
        The user information for the sender (if available)

        :return: The user of this ChatMessage.
        :rtype: ChatMessageUser
        """
        return self._user

    @user.setter
    def user(self, user):
        """
        Sets the user of this ChatMessage.
        The user information for the sender (if available)

        :param user: The user of this ChatMessage.
        :type: ChatMessageUser
        """
        
        self._user = user

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class KnowledgeSearchRequest(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        KnowledgeSearchRequest - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'query': 'str',
            'page_size': 'int',
            'page_number': 'int',
            'document_type': 'str',
            'language_code': 'str',
            'search_on_draft_documents': 'bool'
        }

        self.attribute_map = {
            'query': 'query',
            'page_size': 'pageSize',
            'page_number': 'pageNumber',
            'document_type': 'documentType',
            'language_code': 'languageCode',
            'search_on_draft_documents': 'searchOnDraftDocuments'
        }

        self._query = None
        self._page_size = None
        self._page_number = None
        self._document_type = None
        self._language_code = None
        self._search_on_draft_documents = None

    @property
    def query(self):
        """
        Gets the query of this KnowledgeSearchRequest.
        Input query to search content in the knowledge base

        :return: The query of this KnowledgeSearchRequest.
        :rtype: str
        """
        return self._query

    @query.setter
    def query(self, query):
        """
        Sets the query of this KnowledgeSearchRequest.
        Input query to search content in the knowledge base

        :param query: The query of this KnowledgeSearchRequest.
        :type: str
        """
        
        self._query = query

    @property
    def page_size(self):
        """
        Gets the page_size of this KnowledgeSearchRequest.
        Page size of the returned results

        :return: The page_size of this KnowledgeSearchRequest.
        :rtype: int
        """
        return self._page_size

    @page_size.setter
    def page_size(self, page_size):
        """
        Sets the page_size of this KnowledgeSearchRequest.
        Page size of the returned results

        :param page_size: The page_size of this KnowledgeSearchRequest.
        :type: int
        """
        
        self._page_size = page_size

    @property
    def page_number(self):
        """
        Gets the page_number of this KnowledgeSearchRequest.
        Page number of the returned results

        :return: The page_number of this KnowledgeSearchRequest.
        :rtype: int
        """
        return self._page_number

    @page_number.setter
    def page_number(self, page_number):
        """
        Sets the page_number of this KnowledgeSearchRequest.
        Page number of the returned results

        :param page_number: The page_number of this KnowledgeSearchRequest.
        :type: int
        """
        
        self._page_number = page_number

    @property
    def document_type(self):
        """
        Gets the document_type of this KnowledgeSearchRequest.
        Document type to be used while searching

        :return: The document_type of this KnowledgeSearchRequest.
        :rtype: str
        """
        return self._document_type

    @document_type.setter
    def document_type(self, document_type):
        """
        Sets the document_type of this KnowledgeSearchRequest.
        Document type to be used while searching

        :param document_type: The document_type of this KnowledgeSearchRequest.
        :type: str
        """
        allowed_values = ["Faq"]
        if document_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for document_type -> " + document_type)
            self._document_type = "outdated_sdk_version"
        else:
            self._document_type = document_type

    @property
    def language_code(self):
        """
        Gets the language_code of this KnowledgeSearchRequest.
        query search for specific languageCode

        :return: The language_code of this KnowledgeSearchRequest.
        :rtype: str
        """
        return self._language_code

    @language_code.setter
    def language_code(self, language_code):
        """
        Sets the language_code of this KnowledgeSearchRequest.
        query search for specific languageCode

        :param language_code: The language_code of this KnowledgeSearchRequest.
        :type: str
        """
        
        self._language_code = language_code

    @property
    def search_on_draft_documents(self):
        """
        Gets the search_on_draft_documents of this KnowledgeSearchRequest.
        If true the search query will be executed on draft documents, else it will be on active documents

        :return: The search_on_draft_documents of this KnowledgeSearchRequest.
        :rtype: bool
        """
        return self._search_on_draft_documents

    @search_on_draft_documents.setter
    def search_on_draft_documents(self, search_on_draft_documents):
        """
        Sets the search_on_draft_documents of this KnowledgeSearchRequest.
        If true the search query will be executed on draft documents, else it will be on active documents

        :param search_on_draft_documents: The search_on_draft_documents of this KnowledgeSearchRequest.
        :type: bool
        """
        
        self._search_on_draft_documents = search_on_draft_documents

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class FlowExecutionLaunchRequest(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        FlowExecutionLaunchRequest - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'flow_id': 'str',
            'flow_version': 'str',
            'input_data': 'dict(str, object)',
            'name': 'str'
        }

        self.attribute_map = {
            'flow_id': 'flowId',
            'flow_version': 'flowVersion',
            'input_data': 'inputData',
            'name': 'name'
        }

        self._flow_id = None
        self._flow_version = None
        self._input_data = None
        self._name = None

    @property
    def flow_id(self):
        """
        Gets the flow_id of this FlowExecutionLaunchRequest.
        ID of the flow to launch.

        :return: The flow_id of this FlowExecutionLaunchRequest.
        :rtype: str
        """
        return self._flow_id

    @flow_id.setter
    def flow_id(self, flow_id):
        """
        Sets the flow_id of this FlowExecutionLaunchRequest.
        ID of the flow to launch.

        :param flow_id: The flow_id of this FlowExecutionLaunchRequest.
        :type: str
        """
        
        self._flow_id = flow_id

    @property
    def flow_version(self):
        """
        Gets the flow_version of this FlowExecutionLaunchRequest.
        The version of the flow to launch. Omit this value (or supply null/empty) to use the latest published version.

        :return: The flow_version of this FlowExecutionLaunchRequest.
        :rtype: str
        """
        return self._flow_version

    @flow_version.setter
    def flow_version(self, flow_version):
        """
        Sets the flow_version of this FlowExecutionLaunchRequest.
        The version of the flow to launch. Omit this value (or supply null/empty) to use the latest published version.

        :param flow_version: The flow_version of this FlowExecutionLaunchRequest.
        :type: str
        """
        
        self._flow_version = flow_version

    @property
    def input_data(self):
        """
        Gets the input_data of this FlowExecutionLaunchRequest.
        Input values to the flow. Valid values are defined by a flow's input JSON schema.

        :return: The input_data of this FlowExecutionLaunchRequest.
        :rtype: dict(str, object)
        """
        return self._input_data

    @input_data.setter
    def input_data(self, input_data):
        """
        Sets the input_data of this FlowExecutionLaunchRequest.
        Input values to the flow. Valid values are defined by a flow's input JSON schema.

        :param input_data: The input_data of this FlowExecutionLaunchRequest.
        :type: dict(str, object)
        """
        
        self._input_data = input_data

    @property
    def name(self):
        """
        Gets the name of this FlowExecutionLaunchRequest.
        A displayable name to assign to the new flow execution

        :return: The name of this FlowExecutionLaunchRequest.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this FlowExecutionLaunchRequest.
        A displayable name to assign to the new flow execution

        :param name: The name of this FlowExecutionLaunchRequest.
        :type: str
        """
        
        self._name = name

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class DataTableExportJob(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        DataTableExportJob - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'owner': 'AddressableEntityRef',
            'status': 'str',
            'date_created': 'datetime',
            'date_completed': 'datetime',
            'download_uri': 'str',
            'error_information': 'ErrorBody',
            'count_records_processed': 'int',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'owner': 'owner',
            'status': 'status',
            'date_created': 'dateCreated',
            'date_completed': 'dateCompleted',
            'download_uri': 'downloadURI',
            'error_information': 'errorInformation',
            'count_records_processed': 'countRecordsProcessed',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._owner = None
        self._status = None
        self._date_created = None
        self._date_completed = None
        self._download_uri = None
        self._error_information = None
        self._count_records_processed = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this DataTableExportJob.
        The globally unique identifier for the object.

        :return: The id of this DataTableExportJob.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this DataTableExportJob.
        The globally unique identifier for the object.

        :param id: The id of this DataTableExportJob.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this DataTableExportJob.


        :return: The name of this DataTableExportJob.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this DataTableExportJob.


        :param name: The name of this DataTableExportJob.
        :type: str
        """
        
        self._name = name

    @property
    def owner(self):
        """
        Gets the owner of this DataTableExportJob.
        The PureCloud user who started the export job

        :return: The owner of this DataTableExportJob.
        :rtype: AddressableEntityRef
        """
        return self._owner

    @owner.setter
    def owner(self, owner):
        """
        Sets the owner of this DataTableExportJob.
        The PureCloud user who started the export job

        :param owner: The owner of this DataTableExportJob.
        :type: AddressableEntityRef
        """
        
        self._owner = owner

    @property
    def status(self):
        """
        Gets the status of this DataTableExportJob.
        The status of the export job

        :return: The status of this DataTableExportJob.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this DataTableExportJob.
        The status of the export job

        :param status: The status of this DataTableExportJob.
        :type: str
        """
        allowed_values = ["Processing", "Failed", "Succeeded"]
        if status.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for status -> " + status)
            self._status = "outdated_sdk_version"
        else:
            self._status = status

    @property
    def date_created(self):
        """
        Gets the date_created of this DataTableExportJob.
        The timestamp of when the export began. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The date_created of this DataTableExportJob.
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """
        Sets the date_created of this DataTableExportJob.
        The timestamp of when the export began. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param date_created: The date_created of this DataTableExportJob.
        :type: datetime
        """
        
        self._date_created = date_created

    @property
    def date_completed(self):
        """
        Gets the date_completed of this DataTableExportJob.
        The timestamp of when the export stopped (either successfully or unsuccessfully). Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The date_completed of this DataTableExportJob.
        :rtype: datetime
        """
        return self._date_completed

    @date_completed.setter
    def date_completed(self, date_completed):
        """
        Sets the date_completed of this DataTableExportJob.
        The timestamp of when the export stopped (either successfully or unsuccessfully). Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param date_completed: The date_completed of this DataTableExportJob.
        :type: datetime
        """
        
        self._date_completed = date_completed

    @property
    def download_uri(self):
        """
        Gets the download_uri of this DataTableExportJob.
        The URL of the location at which the caller can download the export file, when available

        :return: The download_uri of this DataTableExportJob.
        :rtype: str
        """
        return self._download_uri

    @download_uri.setter
    def download_uri(self, download_uri):
        """
        Sets the download_uri of this DataTableExportJob.
        The URL of the location at which the caller can download the export file, when available

        :param download_uri: The download_uri of this DataTableExportJob.
        :type: str
        """
        
        self._download_uri = download_uri

    @property
    def error_information(self):
        """
        Gets the error_information of this DataTableExportJob.
        Any error information, or null of the processing is not in an error state

        :return: The error_information of this DataTableExportJob.
        :rtype: ErrorBody
        """
        return self._error_information

    @error_information.setter
    def error_information(self, error_information):
        """
        Sets the error_information of this DataTableExportJob.
        Any error information, or null of the processing is not in an error state

        :param error_information: The error_information of this DataTableExportJob.
        :type: ErrorBody
        """
        
        self._error_information = error_information

    @property
    def count_records_processed(self):
        """
        Gets the count_records_processed of this DataTableExportJob.
        The current count of the number of records processed

        :return: The count_records_processed of this DataTableExportJob.
        :rtype: int
        """
        return self._count_records_processed

    @count_records_processed.setter
    def count_records_processed(self, count_records_processed):
        """
        Sets the count_records_processed of this DataTableExportJob.
        The current count of the number of records processed

        :param count_records_processed: The count_records_processed of this DataTableExportJob.
        :type: int
        """
        
        self._count_records_processed = count_records_processed

    @property
    def self_uri(self):
        """
        Gets the self_uri of this DataTableExportJob.
        The URI for this object

        :return: The self_uri of this DataTableExportJob.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this DataTableExportJob.
        The URI for this object

        :param self_uri: The self_uri of this DataTableExportJob.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other

